@@ -2,7 +2,7 @@
 #ifndef _GLIBMM_USTRING_H
 #define _GLIBMM_USTRING_H
 
-/* $Id: ustring.h,v 1.3 2003/12/22 17:05:10 murrayc Exp $ */
+/* $Id: ustring.h,v 1.6 2004/05/26 20:33:03 daniel Exp $ */
 
 /* Copyright (C) 2002 The gtkmm Development Team
  *
@@ -21,6 +21,7 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#include <glib/gmacros.h>
 #include <glib/gunicode.h>
 #include <glibmm/unicode.h>
 
@@ -133,7 +134,7 @@ private:
  * but it might be useful as utility function if you prefer using
  * std::string even for UTF-8 encoding.
  */
-gunichar get_unichar_from_std_iterator(std::string::const_iterator pos);
+gunichar get_unichar_from_std_iterator(std::string::const_iterator pos) G_GNUC_PURE;
 
 
 /** Glib::ustring has much the same interface as std::string, but contains
@@ -233,26 +234,69 @@ public:
 
   static const size_type npos = std::string::npos;
 
+  /** Default constructor, which creates an empty string.
+   */
   ustring();
+  
   ~ustring();
 
+  /** Construct a ustring as a copy of a ustring
+   * @param other A source string.
+   */
   ustring(const ustring& other);
+
+  /** Assign the value of a string to this string.
+   * @param other A source string
+   */ 
   ustring& operator=(const ustring& other);
 
+  /** Swap contents with another string.
+   * @param other String to swap with.
+   */
   void swap(ustring& other);
 
-//! @name Create new strings.
-//! @{
-
+  /** Construct a ustring as a copy of a std::string
+   * @param src A source std::string containing text encoded as UTF-8.
+   */
   ustring(const std::string& src);
+
+  /** Construct a ustring as a copy of a substring
+   * @param src Source Glib::ustring.
+   * @param i Index of first character to copy from.
+   * @param n Number of characters to copy (default to copying the remainder).
+   */
   ustring(const ustring& src, size_type i, size_type n=npos);
+
+  /** Construct a ustring as a copy of a substring
+   * @param src Source C string encoded as UTF-8.
+   * @param n Number of characters to copy.
+   */
   ustring(const char* src, size_type n);
+
+  /** Construct a ustring as a copy of a substring
+   * @param src Source C string encoded as UTF-8.
+   */
   ustring(const char* src);
+
+  /** Construct a  ustring as multiple characters.
+   * @param n Number of characters.
+   * @param uc UTF-8 character to use.
+   */  
   ustring(size_type n, gunichar uc);
+
+  /** Construct a ustring as multiple characters.
+   * @param n Number of characters.
+   * @param c ASCII character to use.
+   */  
   ustring(size_type n, char c);
+
+  /** Construct a ustring as a copy of a range.
+   * @param pbegin Start of range.
+   * @param pend End of range.
+   */  
   template <class In> ustring(In pbegin, In pend);
 
-//! @}
+
 //! @name Assign new contents.
 //! @{
 
@@ -500,7 +544,7 @@ public:
 //! @{
 
   /*! Returns a new UTF-8 string with all characters characters converted to
-   * their uppercase equivalent, while honoring the current locale.  The
+   * their lowercase equivalent, while honoring the current locale.  The
    * resulting string may change in the number of bytes as well as in the
    * number of characters.  For instance, the German sharp&nbsp;s
    * <tt>"&szlig;"</tt> will be replaced by two characters <tt>"SS"</tt>
@@ -509,7 +553,7 @@ public:
   ustring uppercase() const;
 
   /*! Returns a new UTF-8 string with all characters characters converted to
-   * their uppercase equivalent, while honoring the current locale.  The
+   * their lowercase equivalent, while honoring the current locale.  The
    * resulting string may change in the number of bytes as well as in the
    * number of characters.
    */
@@ -635,24 +679,24 @@ ustring_Iterator<T>& ustring_Iterator<T>::operator++()
 template <class T> inline
 const ustring_Iterator<T> ustring_Iterator<T>::operator++(int)
 {
-  const ustring_Iterator<T> tmp (*this);
+  const ustring_Iterator<T> temp (*this);
   this->operator++();
-  return tmp;
+  return temp;
 }
 
 template <class T> inline
 ustring_Iterator<T>& ustring_Iterator<T>::operator--()
 {
-  do { --pos_; } while((*pos_ & '\xC0') == '\x80');
+  do --pos_; while((*pos_ & '\xC0') == '\x80');
   return *this;
 }
 
 template <class T> inline
 const ustring_Iterator<T> ustring_Iterator<T>::operator--(int)
 {
-  const ustring_Iterator<T> tmp (*this);
+  const ustring_Iterator<T> temp (*this);
   this->operator--();
-  return tmp;
+  return temp;
 }
 
 #endif /* DOXYGEN_SHOULD_SKIP_THIS */
@@ -878,31 +922,31 @@ inline bool operator>=(const char* lhs, const ustring& rhs)
 
 /** @relates Glib::ustring */
 inline ustring operator+(const ustring& lhs, const ustring& rhs)
-  { return ustring(lhs) += rhs; }
+  { ustring temp (lhs); temp += rhs; return temp; }
 
 /** @relates Glib::ustring */
 inline ustring operator+(const ustring& lhs, const char* rhs)
-  { return ustring(lhs) += rhs; }
+  { ustring temp (lhs); temp += rhs; return temp; }
 
 /** @relates Glib::ustring */
 inline ustring operator+(const char* lhs, const ustring& rhs)
-  { return ustring(lhs) += rhs; }
+  { ustring temp (lhs); temp += rhs; return temp; }
 
 /** @relates Glib::ustring */
 inline ustring operator+(const ustring& lhs, gunichar rhs)
-  { return ustring(lhs) += rhs; }
+  { ustring temp (lhs); temp += rhs; return temp; }
 
 /** @relates Glib::ustring */
 inline ustring operator+(gunichar lhs, const ustring& rhs)
-  { return ustring(1, lhs) += rhs; }
+  { ustring temp (1, lhs); temp += rhs; return temp; }
 
 /** @relates Glib::ustring */
 inline ustring operator+(const ustring& lhs, char rhs)
-  { return ustring(lhs) += rhs; }
+  { ustring temp (lhs); temp += rhs; return temp; }
 
 /** @relates Glib::ustring */
 inline ustring operator+(char lhs, const ustring& rhs)
-  { return ustring(1, lhs) += rhs; }
+  { ustring temp (1, lhs); temp += rhs; return temp; }
 
 } // namespace Glib
 
